-- cks.sql - SQL code for database schema establishment
-- Copyright (C) 2001-2005 CryptNET, V. Alex Brennen (VAB)
--
-- This file is part of the CryptNET openPGP Public Key Server (cks).
--
-- cks is free software; you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation; either version 2 of the License, or
-- (at your option) any later version.
--
-- cks is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to the Free Software
-- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
--

drop table cks_keyid_table;
drop table cks_key_info_table;
drop table cks_fp_key_table;
drop table cks_uid_table;
drop table cks_puid_table;
drop table cks_pending_sync;
drop table cks_other_servers;
drop table cks_rejected_keys;


-- Your own userid for testing.
-- change to your username.
create user "_postgres_";

--  The Keyserver user which you can run cksd under.
--  If you use a different userid, change keyserver
--  to that account name.
create user "_cks";

--  The userid that your websever runs under.
--  If you are using a different userid, change 
--  to that userid.  You should not use nobody.
create user "apache";


create table cks_keyid_table
(
        key_id          char(8) NOT NULL,
        fkey_id         char(16) NOT NULL,
        fp              varchar(40) NOT NULL,
        PRIMARY KEY(fp)
);

create index cks_keyid_table_keyid_idx on cks_keyid_table(key_id);
create index cks_keyid_table_fkeyid_idx on cks_keyid_table(fkey_id);

create table cks_key_info_table
(
        fp              varchar(40) NOT NULL,
        key_id          char(8) NOT NULL,
        pgp_vrsn        int2 NOT NULL,
        algorithm       int2 NOT NULL,
        size            int4 NOT NULL,
        c_time          int4 NOT NULL,
        e_time          int4 NOT NULL,
        revoked         int2 NOT NULL,
        PRIMARY KEY(fp)
);

create index cks_key_info_table_idx on cks_key_info_table(key_id,fp);
create index cks_key_info_table_fp_idx on cks_key_info_table(fp);


create table cks_fp_key_table
(
        fp              varchar(40) NOT NULL,
        ecsum           char(4) NOT NULL,
        pgp_key         oid NOT NULL,
        PRIMARY KEY(fp)
);

create table cks_uid_table
(
        fkey_id         varchar(16) NOT NULL,
        p_uid           int2 NOT NULL,
        fp              varchar(40) NOT NULL,
        uid             varchar(6000) NOT NULL
);

create index cks_uid_table_idx on cks_uid_table(fkey_id,p_uid);
create index cks_uid_table_uid_idx on cks_uid_table(uid);
create index cks_uid_table_fp_idx on cks_uid_table(fp);
create index cks_uid_table_fkey_id_idx on cks_uid_table(fkey_id);

-- The puid table is used for displaying sigs during searches
create table cks_puid_table
(
        fkeyid  varchar(16) NOT NULL,
        fp      varchar(40) NOT NULL,
        uid     varchar(8000) NOT NULL
);
create index cks_puid_table_idx on cks_puid_table(fkeyid);
create index cks_puid_table_fp_idx on cks_puid_table(fp);

create table cks_pending_sync
(
        fp              varchar(40) NOT NULL,
        PRIMARY KEY(fp)
);

create index cks_pending_sync_idx on cks_pending_sync(fp);

-- server_type  cks      (http sync)   1
-- server_type  horowits (mail sync)   2
-- server_type  cks-bin  (binary sync) 3

create table cks_other_servers
(
        server          varchar(300) NOT NULL,
        email           varchar(300) NOT NULL,
        server_type     int2 NOT NULL,
        sync_priority   int2 NOT NULL,
        PRIMARY KEY(server)
);

create table cks_rejected_keys
(
        fp              varchar(40) NOT NULL,
        PRIMARY KEY(fp)
);


--  The "apache" user which you can run your web server under.
--  If you use a different userid, change these lines.

grant select on cks_keyid_table to "apache";
grant insert on cks_keyid_table to "apache";
grant update on cks_keyid_table to "apache";
grant delete on cks_keyid_table to "apache";
grant select on cks_key_info_table to "apache";
grant insert on cks_key_info_table to "apache";
grant update on cks_key_info_table to "apache";
grant delete on cks_key_info_table to "apache";
grant select on cks_fp_key_table to "apache";
grant insert on cks_fp_key_table to "apache";
grant update on cks_fp_key_table to "apache";
grant delete on cks_fp_key_table to "apache";
grant select on cks_uid_table to "apache";
grant insert on cks_uid_table to "apache";
grant update on cks_uid_table to "apache";
grant delete on cks_uid_table to "apache";
grant select on cks_puid_table to "apache";
grant insert on cks_puid_table to "apache";
grant update on cks_puid_table to "apache";
grant delete on cks_puid_table to "apache";
grant select on cks_pending_sync to "apache";
grant insert on cks_pending_sync to "apache";
grant update on cks_pending_sync to "apache";
grant delete on cks_pending_sync to "apache";
grant select on cks_other_servers to "apache";
grant insert on cks_other_servers to "apache";
grant update on cks_other_servers to "apache";
grant delete on cks_other_servers to "apache";
grant select on cks_rejected_keys to "apache";
grant insert on cks_rejected_keys to "apache";
grant update on cks_rejected_keys to "apache";
grant delete on cks_rejected_keys to "apache";


--  The "_cks" user which you can run cksd under.
--  If you use a different userid, change these lines.

grant select on cks_keyid_table to "_cks";
grant insert on cks_keyid_table to "_cks";
grant update on cks_keyid_table to "_cks";
grant delete on cks_keyid_table to "_cks";
grant select on cks_key_info_table to "_cks";
grant insert on cks_key_info_table to "_cks";
grant update on cks_key_info_table to "_cks";
grant delete on cks_key_info_table to "_cks";
grant select on cks_fp_key_table to "_cks";
grant insert on cks_fp_key_table to "_cks";
grant update on cks_fp_key_table to "_cks";
grant delete on cks_fp_key_table to "_cks";
grant select on cks_uid_table to "_cks";
grant insert on cks_uid_table to "_cks";
grant update on cks_uid_table to "_cks";
grant delete on cks_uid_table to "_cks";
grant select on cks_puid_table to "_cks";
grant insert on cks_puid_table to "_cks";
grant update on cks_puid_table to "_cks";
grant delete on cks_puid_table to "_cks";
grant select on cks_pending_sync to "_cks";
grant insert on cks_pending_sync to "_cks";
grant update on cks_pending_sync to "_cks";
grant delete on cks_pending_sync to "_cks";
grant select on cks_other_servers to "_cks";
grant insert on cks_other_servers to "_cks";
grant update on cks_other_servers to "_cks";
grant delete on cks_other_servers to "_cks";
grant select on cks_rejected_keys to "_cks";
grant insert on cks_rejected_keys to "_cks";
grant update on cks_rejected_keys to "_cks";
grant delete on cks_rejected_keys to "_cks";


-- Your own userid for testing.
-- change "_postgres_" to your username.

grant select on cks_keyid_table to "_postgres_";
grant insert on cks_keyid_table to "_postgres_";
grant update on cks_keyid_table to "_postgres_";
grant delete on cks_keyid_table to "_postgres_";
grant select on cks_key_info_table to "_postgres_";
grant insert on cks_key_info_table to "_postgres_";
grant update on cks_key_info_table to "_postgres_";
grant delete on cks_key_info_table to "_postgres_";
grant select on cks_fp_key_table to "_postgres_";
grant insert on cks_fp_key_table to "_postgres_";
grant update on cks_fp_key_table to "_postgres_";
grant delete on cks_fp_key_table to "_postgres_";
grant select on cks_uid_table to "_postgres_";
grant insert on cks_uid_table to "_postgres_";
grant update on cks_uid_table to "_postgres_";
grant delete on cks_uid_table to "_postgres_";
grant select on cks_puid_table to "_postgres_";
grant insert on cks_puid_table to "_postgres_";
grant update on cks_puid_table to "_postgres_";
grant delete on cks_puid_table to "_postgres_";
grant select on cks_pending_sync to "_postgres_";
grant insert on cks_pending_sync to "_postgres_";
grant update on cks_pending_sync to "_postgres_";
grant delete on cks_pending_sync to "_postgres_";
grant select on cks_other_servers to "_postgres_";
grant insert on cks_other_servers to "_postgres_";
grant update on cks_other_servers to "_postgres_";
grant delete on cks_other_servers to "_postgres_";
grant select on cks_rejected_keys to "_postgres_";
grant insert on cks_rejected_keys to "_postgres_";
grant update on cks_rejected_keys to "_postgres_";
grant delete on cks_rejected_keys to "_postgres_";

